@@ -8,5 +8,8 @@ class Series:
         for tick in data["ticks"]:
             self.ticks.append(Tick(tick))
 
-    def getTick(self, tickIndex):
-        return self.ticks[tickIndex]
\ No newline at end of file
+    def __getitem__(self, item):
+        return self.ticks[item]
+
+    def __len__(self):
+        return len(self.ticks)
\ No newline at end of file
